package com.streambase.sb.services.examples.JUnit;

import org.junit.After;
import org.junit.AfterClass;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

import com.streambase.sb.unittest.Expecter;
import com.streambase.sb.unittest.JSONSingleQuotesTupleMaker;
import com.streambase.sb.unittest.ObjectArrayTupleMaker;
import com.streambase.sb.unittest.SBServerManager;
import com.streambase.sb.unittest.ServerManagerFactory;

public class TestHierarchLoading {

	private static SBServerManager server;

	@BeforeClass
	public static void setupServer() throws Exception {
		// create a StreamBase server and load applications once for all tests in this class
		server = ServerManagerFactory.getEmbeddedServer();
		server.startServer();
		server.loadApp("Risk_Management_Demo.sbapp");
	}

	@AfterClass
	public static void stopServer() throws Exception {
		if (server != null) {
			server.shutdownServer();
			server = null;
		}
	}

	@Before
	public void startContainers() throws Exception {
		// before each test, startup fresh container instances
		server.startContainers();
	}

	@Test
	public void test1() throws Exception {
		// TODO generated method

		/*
		 * enqueuer using a TupleMaker that converts JSON strings to Tuples.
		 * this will send a hierarchy "add" message to the application
		 */
		String inputTupleAsJSONString;
		inputTupleAsJSONString = "{'Command':'ins','TraderID':'null','Hierarchy':['portf1,null']," +
				"'BidLimit':1500000,'AskLimit':1500000}";
		server.getEnqueuer("HierTblChanges").enqueue(
				JSONSingleQuotesTupleMaker.MAKER, inputTupleAsJSONString);
		

		inputTupleAsJSONString = "{'guiID':'1'}";
		server.getEnqueuer("RequestHierarchyReport").enqueue(
				JSONSingleQuotesTupleMaker.MAKER, inputTupleAsJSONString);

		/*
		 * Example dequeuer using an alternate TupleMaker that converts Java Objects to
		 * Tuples. ObjectArrayTupleMaker maps Java Objects to Tuple field values
		 */
		Expecter expecter = new Expecter(server.getDequeuer("ReportHierarchy"));
		
		String outputTupleAsJSONString = "{'TraderID':'null','Hierarchy':['portf1,null']," +
		"'BidExposureLimit':1500000,'AskExposureLimit':1500000}";
		
		expecter.expect(JSONSingleQuotesTupleMaker.MAKER,outputTupleAsJSONString);
	}

	@After
	public void stopContainers() throws Exception {
		// after each test, dispose of the container instances
		server.stopContainers();
	}

}
